<?php
/**
 * Plugin Name: Plaza Ecommerce plugin
 * Plugin URI: http://www.plazaecommerce.com
 * Description: Woocommerce Plaza Ecommerce Integration.
 * Author:  Gaston Ciani
 * Author URI: https://www.linkedin.com/in/gastonciani/
 * Version: 1.0
 */
if ( ! class_exists( 'WC_plaza_custom_plugin' ) ) :
    class WC_plaza_custom_plugin {
        /**
         * Construct the plugin.
         */
        public function __construct() {
            add_action( 'plugins_loaded', array( $this, 'init' ) );
        }
        /**
         * Initialize the plugin.
         */
        public function init() {
            // Checks if WooCommerce is installed.
            if ( class_exists( 'WC_Integration' ) ) {
                // Include our integration class.
                include_once 'class-wc-integration-plaza-integration.php';
                // Register the integration.
                add_filter( 'woocommerce_integrations', array( $this, 'add_integration' ) );
            }
            // Set the plugin slug
            define( 'MY_PLUGIN_SLUG', 'wc-settings' );

        // Setting action for plugin
            add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'WC_plaza_custom_plugin_action_links' );
        }
        /**
         * Add a new integration to WooCommerce.
         */
        public function add_integration( $integrations ) {
            $integrations[] = 'WC_Plaza_plugin_Integration';
            return $integrations;
        }

    }
    $WC_plaza_custom_plugin = new WC_plaza_custom_plugin( __FILE__ );


    function WC_plaza_custom_plugin_action_links( $links ) {

        $links[] = '<a href="'. menu_page_url( MY_PLUGIN_SLUG, false ) .'&tab=integration">Settings </a>';
        return $links;
    }
endif;

//agrego la funcion que quiero ejecutar cuando se genera una nueva orden
add_action( 'woocommerce_new_order', 'call_order_status_new', 10, 1);

// se ejecuta cuando hay una nueva orden
function call_order_status_new( $order_id  ) {
    // load order
    $order = new WC_Order( $order_id );

    $nuevo_envio = NuevoEnvio($order,$order_id);
    $curlAction = curlAction($nuevo_envio);

    // LOAD THE WC LOGGER
    $logger = wc_get_logger();

    $logger->info( 'Referencia: '.$nuevo_envio['referencia'],array('source','curlAction') );
    $logger->info( 'Resultado: '.$curlAction,array('source','curlAction') );
    $logger->info( '---',array('source','curlAction') );

}



//obtiene credenciales guardadas
function credenciales(){

    $api_keys = get_option( 'woocommerce_plaza-plugin-integration_settings' );

    $credenciales['usuario'] = $api_keys['usuario'];
    $credenciales['clave'] = $api_keys['clave_secreta'];

    return $credenciales;

}


//organiza informacion de la orden y las credenciales
function NuevoEnvio($order,$orderid)
{
    $credenciales = credenciales();

    $domicilio['usuario'] = $credenciales['usuario'];
    $domicilio['referencia'] = "Orden:".$orderid;
    $domicilio['nombre'] = $order->get_shipping_first_name();
    $domicilio['apellido'] = $order->get_shipping_last_name();
    $domicilio['email'] = $order->get_billing_email();
    $domicilio['telefono'] = $order->get_billing_phone();
    $domicilio['descripcion'] = "Producto de ".get_bloginfo( 'name' );
    $domicilio['tipo_envio'] = "domicilio";
    $domicilio['direccion'] = $order->get_shipping_address_1();
    $domicilio['direccion_adicional'] = $order->get_shipping_address_2();
    $domicilio['codigo_region'] = "-";
    $domicilio['ciudad'] = $order->get_shipping_city().', '.$order->get_shipping_state();

    $verificador = Verificador($domicilio,$credenciales['clave']);

    $domicilio['codigo_verificador'] = $verificador;

    return $domicilio;
}

//encode de los parametros + clave privada
function Verificador($params,$password){
    $params_implode = implode('',$params);
    $toSha = $params_implode.$password;
    $sha1 = sha1($toSha);
    return $sha1;
}

// curl de los nuevos envios
function curlAction($request){

    $url = 'https://plazaecommerce.com/api/nuevo/envio/';
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 1);
    curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 1);
    curl_setopt($ch, CURLOPT_POSTFIELDS, $request);
    $responseBody = curl_exec($ch);
    curl_close ($ch);

    return $responseBody;

}